High Level GUI and Media (highgui module) {#tutorial_table_of_content_highgui}
=========================================

This section contains tutorials about how to use the built-in graphical user interface of the library.

-   @subpage tutorial_trackbar

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 2.0

    *Author:* Ana Huamán

    We will learn how to add a Trackbar to our applications
